# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class OperationSuspEventsRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'OperationSuspEvents','sas')
		self.set_method('POST')

	def get_SuspiciousEventIds(self):
		return self.get_query_params().get('SuspiciousEventIds')

	def set_SuspiciousEventIds(self,SuspiciousEventIds):
		self.add_query_param('SuspiciousEventIds',SuspiciousEventIds)

	def get_SubOperation(self):
		return self.get_query_params().get('SubOperation')

	def set_SubOperation(self,SubOperation):
		self.add_query_param('SubOperation',SubOperation)

	def get_SourceIp(self):
		return self.get_query_params().get('SourceIp')

	def set_SourceIp(self,SourceIp):
		self.add_query_param('SourceIp',SourceIp)

	def get_WarnType(self):
		return self.get_query_params().get('WarnType')

	def set_WarnType(self,WarnType):
		self.add_query_param('WarnType',WarnType)

	def get_From(self):
		return self.get_query_params().get('From')

	def set_From(self,_From):
		self.add_query_param('From',_From)

	def get_Operation(self):
		return self.get_query_params().get('Operation')

	def set_Operation(self,Operation):
		self.add_query_param('Operation',Operation)